@@ -21,6 +21,7 @@ class TestOpenApi3HttpDomain(object):
                             ('kind', {
                                 'description': 'Kind',
                                 'type': 'string',
+                                'readOnly': True,
                             }),
                             ('instance', {
                                 '$ref': '#/components/schemas/Instance',
@@ -34,10 +35,17 @@ class TestOpenApi3HttpDomain(object):
                                 'description': 'Instance',
                                 'type': 'string',
                                 'enum': ['A', 'B'],
+                                'writeOnly': True,
+                                'deprecated': True,
                             }),
                             ('instanceType', {
                                 '$ref': '#/components/schemas/InstanceType',
                             }),
+                            ('dep', {
+                                'description': 'Deprecation',
+                                'type': 'string',
+                                'deprecated': True,
+                            }),
                         ]),
                     },
                     'InstanceList': {
@@ -68,10 +76,10 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``kind``
               - string
-              - Kind
+              - Kind. Constraints: read only
               - Yes
             * - ``instance``
               - Object of type :ref:`Instance </components/schemas/Instance>`
@@ -92,15 +100,23 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``instance``
               - string
-              - Instance. Constraints: possible values are ``A``, ``B``
+              - Instance. Constraints: possible values are ``A``, ``B``; write only
+
+                **DEPRECATED**
               -
             * - ``instanceType``
               - string
               - Constraints: possible values are ``T1``, ``T2``
               -
+            * - ``dep``
+              - string
+              - Deprecation.
+
+                **DEPRECATED**
+              -
 
 
         .. _/components/schemas/InstanceList:
@@ -116,7 +132,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - N/A
               - Array of :ref:`Instance </components/schemas/Instance>`
               -
@@ -157,7 +173,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``kind``
               - string
               - Kind
@@ -207,7 +223,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``field1``
               - integer/int32
               - Signed 32 bits
@@ -283,7 +299,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - N/A
               - Array
               -
@@ -307,7 +323,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``table``
               - Array
               -
@@ -361,7 +377,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``field1``
               - integer/int32
               - Signed *32* bits. Default: ``5``.
@@ -400,7 +416,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``field1``
               - integer/int32
               -
@@ -448,7 +464,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``field1``
               - integer/int32
               -
@@ -503,7 +519,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``field1``
               - integer/int32
               -
@@ -568,7 +584,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``...``
               - One of string, integer, number, boolean, :ref:`Test4 </components/schemas/Test4>`
               - Additional properties
@@ -588,7 +604,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``field2``
               - One of string, integer, number, boolean
               -
@@ -608,7 +624,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - N/A
               - One of :ref:`Test4 </components/schemas/Test4>`, object
               -
@@ -628,7 +644,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``field4``
               - string
               -
@@ -688,7 +704,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``...``
               - All of string, integer, number, boolean, :ref:`Test4 </components/schemas/Test4>`
               - Additional properties
@@ -708,7 +724,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``field2``
               - All of string, integer, number, boolean
               -
@@ -728,7 +744,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - N/A
               - All of :ref:`Test4 </components/schemas/Test4>`, object
               -
@@ -748,7 +764,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``field4``
               - string
               -
@@ -808,7 +824,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``...``
               - Any of string, integer, number, boolean, :ref:`Test4 </components/schemas/Test4>`
               - Additional properties
@@ -828,7 +844,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``field2``
               - Any of string, integer, number, boolean
               -
@@ -848,7 +864,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - N/A
               - Any of :ref:`Test4 </components/schemas/Test4>`, object
               -
@@ -868,7 +884,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``field4``
               - string
               -
@@ -912,7 +928,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``a``
               - string
               -
@@ -932,7 +948,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``ab``
               - string
               -
@@ -955,7 +971,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``a``
               - string
               -
@@ -978,7 +994,7 @@ class TestOpenApi3HttpDomain(object):
             * - Attribute
               - Type
               - Description
-              - Mandatory
+              - Required
             * - ``b``
               - string
               -
