@@ -15,6 +15,8 @@ import collections
 import py
 import pytest
 
+import yaml
+
 from sphinxcontrib.openapi import renderers
 from sphinxcontrib.openapi import openapi20
 from sphinxcontrib.openapi import utils
@@ -656,7 +658,13 @@ class TestOpenApi2HttpDomain(object):
 class TestOpenApi3HttpDomain(object):
 
     def test_basic(self):
-        renderer = renderers.HttpdomainOldRenderer(None, {})
+        renderer = renderers.HttpdomainOldRenderer(
+            None,
+            {
+                'examples': True,
+                'group_examples': True
+            }
+        )
         text = '\n'.join(renderer.render_restructuredtext_markup({
             'openapi': '3.0.0',
             'paths': {
@@ -676,6 +684,13 @@ class TestOpenApi3HttpDomain(object):
                                 'in': 'query',
                                 'schema': {'type': 'integer'},
                                 'description': 'Show up to `limit` entries.',
+                                'required': True,
+                            },
+                            {
+                                'name': 'offset',
+                                'in': 'query',
+                                'schema': {'type': 'integer'},
+                                'description': 'Start from offset.',
                             },
                             {
                                 'name': 'If-None-Match',
@@ -717,10 +732,42 @@ class TestOpenApi3HttpDomain(object):
                   Kind of resource to list.
                :query integer limit:
                   Show up to `limit` entries.
-               :status 200:
-                  An array of resources.
+                  (Required)
+               :query integer offset:
+                  Start from offset.
                :reqheader If-None-Match:
                   Last known resource ETag.
+               :status 200:
+                  An array of resources.
+
+               **Example request:**
+
+               .. sourcecode:: http
+
+                  GET /resources/{kind}?limit=1&offset=1 HTTP/1.1
+                  Host: example.com
+                  Content-Type: application/json
+
+                  {"foo2": "bar2"}
+
+
+               **Example request:**
+
+               .. sourcecode:: http
+
+                  GET /resources/{kind}?limit=1&offset=1 HTTP/1.1
+                  Host: example.com
+
+
+               **Example response:**
+
+               .. sourcecode:: http
+
+                  HTTP/1.1 200 OK
+                  Content-Type: application/json
+
+                  {"foo": "bar"}
+
         ''').lstrip()
 
     def test_rfc7807(self):
@@ -885,6 +932,7 @@ class TestOpenApi3HttpDomain(object):
                     'get': {
                         'summary': 'Index',
                         'description': '~ some useful description ~',
+                        'deprecated': True,
                         'responses': {
                             '200': {
                                 'description': 'Index',
@@ -1019,6 +1067,8 @@ class TestOpenApi3HttpDomain(object):
 
                ~ some useful description ~
 
+               **DEPRECATED**
+
                :status 200:
                   Index
         ''').lstrip()
@@ -1088,11 +1138,11 @@ class TestOpenApi3HttpDomain(object):
                :query integer limit:
                   Show up to `limit` entries.
                   (Required)
-               :status 200:
-                  An array of resources.
                :reqheader If-None-Match:
                   Last known resource ETag.
                   (Required)
+               :status 200:
+                  An array of resources.
         ''').lstrip()
 
     def test_example_generation(self):
@@ -1274,6 +1324,8 @@ class TestOpenApi3HttpDomain(object):
                :query integer limit:
                   Show up to `limit` entries.
                   (Required)
+               :reqheader If-None-Match:
+                  Last known resource ETag.
 
                **Example request:**
 
@@ -1300,8 +1352,6 @@ class TestOpenApi3HttpDomain(object):
                          }
                      ]
 
-               :reqheader If-None-Match:
-                  Last known resource ETag.
 
             .. http:post:: /resources/
                :synopsis: Create Resource
@@ -1775,6 +1825,133 @@ class TestOpenApi3HttpDomain(object):
                   ok
         ''').lstrip()
 
+    def test_header_example(self):
+        renderer = renderers.HttpdomainOldRenderer(None, {'examples': True})
+        spec = yaml.safe_load(textwrap.dedent("""
+        ---
+        openapi: 3.0.0
+        paths:
+          /resources:
+            post:
+              summary: Summary
+              description: test service
+              parameters:
+                - name: Digest
+                  in: header
+                  description: request header
+                  schema:
+                    type: string
+                  example: "MD5=thvDyvhfIqlvFe+A9MYgxAfm1q5="
+              requestBody:
+                content:
+                  application/json:
+                    schema:
+                      type: string
+                    example: REQUEST
+                    required: true
+              responses:
+                200:
+                  description: Success
+                  content:
+                    application/json:
+                      schema:
+                        type: string
+                      example: RESPONSE
+                  headers:
+                    digest:
+                      description: response header
+                      schema:
+                        type: string
+                      example: "MD5=thvDyvhfIqlvFe+A9MYgxAfm1q5="
+        """))
+
+        text = '\n'.join(renderer.render_restructuredtext_markup(spec))
+        assert text == textwrap.dedent('''
+            .. http:post:: /resources
+               :synopsis: Summary
+
+               **Summary**
+
+               test service
+
+               :reqheader Digest:
+                  request header
+
+               **Example request:**
+
+               .. sourcecode:: http
+
+                  POST /resources HTTP/1.1
+                  Host: example.com
+                  Content-Type: application/json
+                  Digest: MD5=thvDyvhfIqlvFe+A9MYgxAfm1q5=
+
+                  REQUEST
+
+               :resheader digest:
+                  response header
+               :status 200:
+                  Success
+
+                  **Example response:**
+
+                  .. sourcecode:: http
+
+                     HTTP/1.1 200 OK
+                     Content-Type: application/json
+                     Digest: MD5=thvDyvhfIqlvFe+A9MYgxAfm1q5=
+
+                     RESPONSE
+
+        ''').lstrip()
+
+        renderer = renderers.HttpdomainOldRenderer(
+            None,
+            {
+                'examples': True,
+                'group_examples': True
+            }
+        )
+        text = '\n'.join(renderer.render_restructuredtext_markup(spec))
+        assert text == textwrap.dedent('''
+            .. http:post:: /resources
+               :synopsis: Summary
+
+               **Summary**
+
+               test service
+
+               :reqheader Digest:
+                  request header
+               :resheader digest:
+                  response header
+               :status 200:
+                  Success
+
+               **Example request:**
+
+               .. sourcecode:: http
+
+                  POST /resources HTTP/1.1
+                  Host: example.com
+                  Content-Type: application/json
+                  Digest: MD5=thvDyvhfIqlvFe+A9MYgxAfm1q5=
+
+                  REQUEST
+
+
+               **Example response:**
+
+               .. sourcecode:: http
+
+                  HTTP/1.1 200 OK
+                  Content-Type: application/json
+                  Digest: MD5=thvDyvhfIqlvFe+A9MYgxAfm1q5=
+
+                  RESPONSE
+
+        ''').lstrip()
+
 
 class TestResolveRefs(object):
 
